@@ -56,7 +56,7 @@ except ImportError:
     MAX_FONT_SIZE = 99
 
 
-__version__ = '0.3.20'
+__version__ = '0.3.21'
 
 
 class AutoFontSizeBehavior:
@@ -90,14 +90,14 @@ class AutoFontSizeBehavior:
     """ maximum font size.
 
     :attr:`auto_font_max_size` is a :class:`~kivy.properties.NumericProperty` and defaults to
-    min(:data:`~ae.gui_app.MAX_FONT_SIZE`, :attr:`~ae.kivy_app.FrameworkApp.max_font_size`).
+    min(:data:`~ae.gui_app.MAX_FONT_SIZE`, :attr:`~ae.kivy.apps.FrameworkApp.max_font_size`).
     """
 
     auto_font_min_size: float = NumericProperty()
     """ minimum font size.
 
     :attr:`auto_font_min_size` is a :class:`~kivy.properties.NumericProperty` and defaults to
-    max(:data:`~ae.gui_app.MIN_FONT_SIZE`, :attr:`~ae.kivy_app.FrameworkApp.min_font_size`).
+    max(:data:`~ae.gui_app.MIN_FONT_SIZE`, :attr:`~ae.kivy.apps.FrameworkApp.min_font_size`).
     """
 
     auto_font_text_spacing: float = NumericProperty('18sp')
